==> hindent-5.2.7-64-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-EqZjNFxOUzVIrKxroM88qt
key: hindent-5.2.7-EqZjNFxOUzVIrKxroM88qt
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 0576d62911596b7aaa486da4759f4a49
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.6.3/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.6.3/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-EqZjNFxOUzVIrKxroM88qt
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff
    filepath-1.4.2.1 haskell-src-exts-1.21.0-3Y5dAzuy9mt34gn6xLKnn0
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.5.0 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.0.0-6w4ARTr2dSVLwsnh8Hr84P
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hindent-5.2.7-65-x86_64.pkg.tar.xz: usr/share/haskell/register/hindent.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hindent
version: 5.2.7
id: hindent-5.2.7-3YyFOLYWJUr3DGcUOKTzfz
key: hindent-5.2.7-3YyFOLYWJUr3DGcUOKTzfz
license: BSD-3-Clause
copyright: 2014 Chris Done, 2015 Andrew Gibiansky
maintainer: chrisdone@gmail.com
author: Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker
stability: Unstable
homepage: https://github.com/commercialhaskell/hindent
synopsis: Extensible Haskell pretty printer
description:
    Extensible Haskell pretty printer. Both a library and an executable.
    .
    See the Github page for usage\/explanation: <https://github.com/commercialhaskell/hindent>
category: Development
abi: 6cecb1f524dd887532011381a1f64288
exposed: True
exposed-modules:
    HIndent HIndent.CabalFile HIndent.Pretty HIndent.Types
import-dirs: /usr/lib/ghc-8.6.3/site-local/hindent-5.2.7
library-dirs: /usr/lib/ghc-8.6.3/site-local/hindent-5.2.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hindent
hs-libraries: HShindent-5.2.7-3YyFOLYWJUr3DGcUOKTzfz
depends:
    Cabal-2.4.0.1 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    directory-1.3.3.0 exceptions-0.10.0-29UXSV5bKJ4B0H4dLl5Nff
    filepath-1.4.2.1 haskell-src-exts-1.21.0-3Y5dAzuy9mt34gn6xLKnn0
    monad-loops-0.4.3-EUyUG8IgG57IqzUQzuXocA mtl-2.2.2 text-1.2.3.1
    transformers-0.5.5.0 utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
    yaml-0.11.0.0-8olqoCOss2r8CW0XUie7op
haddock-interfaces: /usr/share/doc/hindent/html/hindent.haddock
haddock-html: /usr/share/doc/hindent/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
